## dbt-adapters 1.18.0 - November 04, 2025

### Features

- Add default macros for interpolating the volatility of sql UDFs ([#1345](https://github.com/dbt-labs/dbt-adapters/issues/1345))
- Begin looking up function macro by function type ([#1344](https://github.com/dbt-labs/dbt-adapters/issues/1344))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
